# 什么是实验设计？

试验设计，也称为实验设计。数理统计的一个分支。  
关于如何按照预定目标制订适当的实验方案，以利于对实验结果进行有效的统计分析的数学原理和实施方法。  

一个实验的设计，即对实验的一种安排，  
需要考虑实验所要解决的问题类型、对结论赋予何种程度的普遍性、希望以多大功效作检验、试验单元的齐性、每次试验的耗资耗时等方面，  
选取适当的因子和相应的水平，从而给出实验实施的具体程序和数据分析的框架。  

从20世纪20年代费希尔（R.A.Fisher）在农业生产中使用试验设计方法以来，  
试验设计方法已经得到广泛的发展，统计学家们发现了很多非常有效的试验设计技术。  
20世纪50年代，日本统计学家田口玄一将试验设计中应用最广的正交设计表格化，在方法解说方面深入浅出为试验设计的更广泛使用作出了众所周知的贡献。  

## 什么是好的试验设计？

第一是明确衡量产品质量的指标，
    6σ管理强调用数据说话，所以这个质量指标必须是能够量化的指标，
    在试验设计中称为试验指标，也称为响应变量 (response variable）或输出变量。  

第二是寻找影响试验指标的可能因素（factor) ，也称为影响因子和输入变量。  
    因素变化的各种状态称为水平，要求根据专业知识初步确定因素水平的范围。  

第三是根据实际问题，选择适用的试验设计方法。  
    试验设计的方法有很多，每种方法都有不同的适用条件，  
    选择了适用的方法就可以事半而功倍，选择的方法不正确或者根本没有进行有效的试验设计就会事倍而功半。  

第四是科学地分析试验结果，  
    包括对数据的直观分析、方差分析、回归分析等多种统计分析方法，这些工作可以借助Minititab软件完成。  

## 作用

试验设计在工业生产和工程设计中能发挥重要的作用，主要有：
```text
1.提高产量；
2.减少质量的波动，提高产品质量水准；
3.大大缩短新产品试验周期；
4.降低成本；
5.试验设计延长产品寿命。
```

在工农业生产和科学研究中，经常需要做试验，以求达到预期的目的。  
例如在工农业生产中希望通过试验达到高质、优产、低消耗，特别是新产品试验，未知的东西很多，要通过试验来摸索工艺条件或配方。  
如何做试验，其中大有学问。试验设计得好，会事半功倍，反之会事倍功半，甚至劳而无功。  

如果要最有效地进行科学试验，必须用科学方法来设计。  
所谓试验的统计设计，就是设计试验的过程，使得收集的数据适合于用统计方法分析，得出有效的和客观的结论。  
如果想从数据作出有意义的结论，用统计方法作试验设计是必要的。  
当问题涉及到受试验误差影响的数据时，只有统计方法才是客观的分析方法。  
这样一来，任一试验问题就存在两个方面：试验的设计和数据的统计分析。  
这两个课题是紧密相连的，因为分析方法直接依赖于所用的设计。  

## 基本原理

试验设计的三个基本原理是重复，随机化以及区组化。  

* 重复

意思是基本试验的重复进行。  
重复有两条重要的性质。
```text
第一，允许试验者得到试验误差的一个估计量。  
    这个误差的估计量成为确定数据的观察差是否是统计上的试验差的基本度量单位。  

第二，如果样本均值用作为试验中一个因素的效应的估计量，则重复允许试验者求得这一效应的更为精确的估计量。  
    如s2是数据的方差，而有n次重复，则样本均值的方差是s2/n。
    这一点的实际含义是，如果n=1，如果2个处理的y1=145，和y2=147，这时我们可能不能作出2个处理之间有没有差异的推断，
    也就是说，观察差147-145=2可能是试验误差的结果。
    但如果n合理的大，试验误差足够小，则当我们观察得y1随机化是试验设计使用统计方法的基石。
```

* 随机化

是指试验材料的分配和试验的各个试验进行的次序，都是随机地确定的。  
统计方法要求观察值（或误差）是独立分布的随机变量。随机化通常能使这一假定有效。  
把试验进行适当的随机化亦有助于“均匀”可能出现的外来因素的效应。  

* 区组化

是用来提高试验的精确度的一种方法。  
一个区组就是试验材料的一个部分，相比于试验材料全体它们本身的性质应该更为类似。  
区组化牵涉到在每个区组内部对感兴趣的试验条件进行比较。  

## 方法

* 正交试验设计法

① 定义
正交试验设计法是研究与处理多因素试验的一种科学方法。
它利用一种规格化的表格——正交表，挑选试验条件，安排试验计划和进行试验，并通过较少次数的试验，找出较好的生产条件，即最优或较优的试验方案。  

② 用途
正交试验设计主要用于调查复杂系统（产品、过程）的某些特性或多个因素对系统（产品、过程）某些特性的影响，  
识别系统中更有影响的因素、其影响的大小，以及因素间可能存在的相互关系，  
以促进产品的设计开发和过程的优化、控制或改进现有的产品（或系统）。

*  析因法   

① 定义

因法又称析因试验设计、析因试验等。它是研究变动着的两个或多个因素效应的有效方法。许多试验要求考察两个或多个变动因素的效应。  
例如，  
若干因素：对产品质量的效应；  
对某种机器的效应；对某种材料的性能的效应；  
对某一过程燃烧消耗的效应等等。  
将所研究的因素按全部因素的所有水平（位级）的一切组合逐次进行试验，称为析因试验，或称完全析因试验，简称析因法。  

② 用途  

用于新产品开发、产品或过程的改进、以及安装服务，通过较少次数的试验，找到优质、高产、低耗的因素组合，达到改进的目的。  

## 成功要素

```text
1. 没有一种“放之四海而皆准”的问题解决方案，试验设计同样不能提供解决所有问题的途径，要全面考虑解决问题的方式，选取最有效、最经济的解决途径。 　
2. 即使决定采用试验设计，也不能生搬硬套地使用“试验设计五步曲”。  
    跟据实际情况和要求，有时可以省去其中的某几步，有时还会在同一个项目中重复循环地跳几轮“五步曲”。  
3. 除了试验设计涉及的因素外，要尽量确保所有的环境因素是稳定和符合现实的。如果条件所限，如果做不到这一点，不妨可以用随机化、区组化、仿行等方法来尽量避免。  
4. 保证试验的仿真性，避免一些理想的试验环境，比如试验室。  
5. 不要一味地排斥试验设计执行之前的历史数据。  
    相反，适当地利用企业信息化的成果，从ERP、MES中的海量数据中进行“数据挖掘”，很可能会减少试验投资，细化因素水平的选取。  
    这也是当前试验设计应用领域中的新趋势之一。
6. 为了保险起见，在得到最终的最佳参数水平组合后，还要进行一些验证试验来检验结果，  
    实在没有条件实施验证试验的，也要通过模型的“模拟仿真”来完成这个工作。  
7. 工欲善其事，必先利其器。为了提高试验设计的效率和解决问题的成功率，选择合适的专业工具必不可少。  
    源于全球最大统计分析软件公司的JMP软件是试验设计业界的不二选择，它不但能很好地实现筛选试验、析因试验、优化试验等传统手法，  
    而且将数据挖掘、模拟仿真等相关方法也有机地融合在试验设计中，为我们提供了完整的试验设计解决方案，
    本文中的所有图形就完全是以JMP软件为载体实现的，JMP也是目前试验设计方法实践者最推崇的专业软件之一。
```
