# 什么是统计学？

收集、处理、分析、解释数据并从数据中得出结论的科学。  

一级学科
是通过搜索、整理、分析、描述数据等手段，以达到推断所测对象的本质，甚至预测对象未来的一门综合性科学。  
统计学用到了大量的数学及其它学科的专业知识，其应用范围几乎覆盖了社会科学和自然科学的各个领域。   

德国的斯勒兹曾说过：“统计是动态的历史，历史是静态的统计”。

分析思维是数据科学的核心思维方式，而分析思维就是关于计算与统计的思维。  
统计思维生长的土壤就是概率论和数理统计。  

## 发展过程

从统计学的发展历史来看，最早的统计学和国家经济学有密切的关系。  
统计学的英文是“statistic”，其实它是源于意大利文的“stato”，意思是“国家”、“情况”，  
也就是后来英语里的state（国家），在十七、十八世纪，统计学很多时候都是以经济学的姿态出现的。  

统计学最开始来源于经济学和政治学。17世纪的经济学家William Petty和他的《政治算术》一书揭开了统计学的起源。
所以从一开始，统计学就跟经济学、政治学密不可分的。

新中国成立初期，随着计划经济的施行，确切的了解国民经济运行情况是政府最关心的问题之一，  
所以统计学这个时候被理解为“经济统计”是再正常不过的了。  
所以从历史上看，统计学一开始是作为经济学的二级学科而存在的。

这也就成了现在“统计学”这门学科的乱象：即可以授经济学学位，又可以授理学学位。
授经济学学位的“统计学”更偏重于跟国民经济核算相关的内容。  

从培养方式来讲，这和数理统计的培养方式会有很大不同。  
为了进行正常的国民经济核算，除了要掌握基本的统计知识，包括抽样理论等，还要掌握会计学以及一些经济学的知识。  
具体的，比如GDP、GNP、CPI、PPI是怎么计算出来的，以及投入产出表等，都是这类统计学的专业内容。不懂会计、经济学，很难搞明白这些东西。  
这类专业最对口的是会计、统计局、调查所这些地方，因为学科设计出来本来就是为了核算的。  

然而，随着科学技术文化的飞速发展，传统的“统计学”已经远远无法满足需要了。  
因此，在过去一百年间“数理统计”这个词出现并不断发展，同时也促进了让统计学脱离经济学这个小范围，迈向了更大的应用空间。  
“数理统计”逐渐发展为一个跟数学密切相关，并且侧重于非“经济统计”的学科。  

* 统计学发展的另一个源头就是概率论  

16世纪初，概率论的体系渐渐发展起来，而这要从一种和掷骰子有关的赌博活动说起。  
虽然这个活动并不是很光彩，而且有待考证，但是在欧洲兴起并兴盛的骰子赌博活动，引起了一批好奇的学者的关注。  

掷骰子得到的点数直接决定赌局的输赢，于是开始研究各种点数出现的机遇的大小，胜率的大小，  
最早开始数量研究并且给概率下定义的学者已经无从考证了，可是有一些著作的问世和问题的讨论对概率统计的发展产生了重大的影响，  
比如卡丹诺的《机遇博弈》、惠更斯的《机遇的规律》、伯努利的《推测数》、著名的分赌本问题、帕斯卡和费马之间的通信等等，  
在这期间，古典概型得到了极大的发展，概率、期望、二项分布、中心极限定理等概念被相继提出。  
而之后的几百年里，中心极限定理的渐渐完善的过程中，一系列的统计量相继被提出，这也构成了大样本方法的基础。

概率论是统计学的基础，统计学是概率论的发展，二者密不可分。    

可以认为统计学是概率论的应用，是强调统计推断，包括统计决断、估计、检验等问题的一门学科。  

统计里更加关注的是数据与模型。  
模型就是变量与响应之间的关系，简单的比如线性回归模型，  
时间序列分析里的ARIMA GARCH模型，复杂的如SVM或者深度学习里的CNN、RNN等。  

这些模型的范围是什么？适用于怎样的数据类型？  
除此之外，统计学还要回答，在给出数据以后，这些数据能不能用上面的模型进行分析？  
这里就有各种假设检验，模型参数检验，数据分布的非参数检验，数据均匀性的均匀性检验。  
最后，统计学还要回答各类模型预测的效果怎么样，数据要怎么获取更省钱或者让模型效果更好，怎样更节约的使用数据，等等问题。  

### 起源

统计学的英文statistics最早源于现代拉丁文Statisticum Collegium（国会）、  
意大利文Statista（国民或政治家）以及德文Statistik，  

最早是由Gottfried Achenwall于1749年使用，代表对国家的资料进行分析的学问，也就是“研究国家的科学”。  
十九世纪，统计学在广泛的数据以及资料中探究其意义，并且由John Sinclair引进到英语世界。  

统计学是一门很古老的科学，一般认为其学理研究始于古希腊的亚里士多德时代，迄今已有两千三百多年的历史。  
它起源于研究社会经济问题，在两千多年的发展过程中，  
统计学至少经历了“城邦政情”、“政治算数”和“统计分析科学”三个发展阶段。 

所谓“数理统计”并非独立于统计学的新学科，确切地说，  
它是统计学在第三个发展阶段所形成的所有收集和分析数据的新方法的一个综合性名词。   

概率论是数理统计方法的理论基础，但是它不属于统计学的范畴，而是属于数学的范畴。  

* 城邦政情  

“城邦政情”（Matters of state）阶段始于古希腊的亚里斯多德撰写“城邦政情”或“城邦纪要”。  
他一共撰写了一百五十余种纪要，其内容包括各城邦的历史、行政、科学、艺术、人口、资源和财富等社会和经济情况的比较、分析，具有社会科学特点。  
“城邦政情”式的统计研究延续了一两千年，直至十七世纪中叶才逐渐被“政治算术”这个名词所替代，并且很快被演化为“统计学”（Statistics）。  
但统计学依然保留了城邦（state）这个词根。  

* 政治算术  

与“城邦政情”阶段没有很明显的分界点，本质的差别也不大。  
“政治算术”的特点是统计方法与数学计算和推理方法开始结合。分析社会经济问题的方式更加注重运用定量分析方法。  
1690年英国威廉·配弟出版《政治算数》一书作为这个阶段的起始标志。  

威廉·配第用数字、重量和尺度将社会经济现象数量化的方法是近代统计学的重要特征。  
因此，威廉·配第的《政治算术》被后来的学者评价为近代统计学的来源，威廉·配第本人也被评价为近代统计学之父。  

配第在书中使用的数字有三类：  

第一类是对社会经济现象进行统计调查和经验观察得到的数字。   
    因为受历史条件的限制，书中通过严格的统计调查得到的数据少，根据经验得出的数字多；  

第二类是运用某种数学方法推算出来的数字。  
其推算方法可分为三种：  
```text
(1)以已知数或已知量为基础，循著某种具体关系进行推算的方法；
(2)通过运用数字的理论性推理来进行推算的方法；
(3)以平均数为基础进行推算的方法”；  
```

第三类是为了进行理论性推理而采用的例示性的数字。  
配第把这种运用数字和符号进行的推理称之为“代数的算法”。  
从配第使用数据的方法看，“政治算数”阶段的统计学已经比较明显地体现了“收集和分析数据的科学和艺术”特点，  
统计实证方法和理论分析方法浑然一体，这种方法即使是现代统计学也依然继承。  

* 统计分析科学  

在“政治算术”阶段出现的统计与数学的结合趋势逐渐发展形成了“统计分析科学”。
十九世纪末，欧洲大学开设的“国情纪要”或“政治算数”等课程名称逐渐消失，代之而起的是“统计分析科学”课程。  
当时的“统计分析科学”（Science of statistical analysis）课程的内容仍然是分析研究社会经济问题。  

“统计分析科学”课程的出现是现代统计发展阶段的开端。  
1908年，“学生”氏（William Sleey Gosset的笔名Student）发表了关于t分布的论文。  
这是一篇在统计学发展史上划时代的文章，它创立了小样本代替大样本的方法，开创了统计学的新纪元。  

现代统计学的代表人物首推比利时统计学家奎特莱（Adolphe Quelet），  
他将统计分析科学广泛应用于社会科学，自然科学和工程技术科学领域，  
因为他深信统计学是可以用于研究任何科学的一般研究方法。  

现代统计学的理论基础概率论始于研究赌博的机遇问题，大约开始于1477年。  
数学家为了解释支配机遇的一般法则进行了长期的研究，逐渐形成了概率论理论框架。  
在概率论进一步发展的基础上，到十九世纪初，数学家们逐渐建立了观察误差理论，正态分布理论和最小平方法则。  
于是，现代统计方法便有了比较坚实的理论基础。  

## 统计是数学吗？  

在学习统计的时候，特别是在推导概率分布的时候会发现，统计上用微积分证明的地方太多。  
但是统计对于数学的其他方面，比如拓扑，数论等基本完全不涉及。  
因此，首先数学是比统计更加宽泛的学科。  

统计和概率论是平行的两个不同的理念。  
概率论是假设你已经知道了整体然后对一个事件的发生概率进行计算。  
而统计是指你不完全理解整体，你的目的就是为了理解整体的。  
但是整体的数量太大。所以你退而求其次，用抽样的方法来获得理解整体。  
但是抽样就意味着有误差，而误差有的时候会因为你抽样方法的选择或者随机事件的爆发而变的很大。  
这点在数学上很多人不能接受，数学更讲究精确。而且对于很多学数学的人来说，只有对或者错。例如抽象代数。  
所以数学上有一部分人不喜欢统计，会说统计是变魔术。  

总的来说，一个可以接受的观点是：  
概率论是纯数学，数理统计是应用数学，而统计学则是借鉴了概率论和数理统计的一门超级应用学科（数学）。  

## vs 概率论

概率论是统计学的基础，而随机事件的概率是概率论研究的基本内容。  

概率论是统计学的基础，统计学是概率论的发展，二者密不可分。    
可以认为统计学是概率论的应用，是强调统计推断，包括统计决断、估计、检验等问题的一门学科。  

统计里更加关注的是数据与模型。  

## 统计学VS人工智能

从统计学三个大的发展阶段可以看出，统计学经历了实践→理论→检验三个时期，  
当前统计学主要是通过对数据的描述与分析来进行对未来的推断，这与AI的定义十分相似。  

1988年，美国科学家朱迪亚·皮尔将概率统计方法引入人工智能的推理过程中。  
后来，IBM的沃森研究中心把概率统计方法引入到Candide项目——一个基于200多万条语句实现了英语和法语之间的自动翻译。  

1992年，华人李开复使用统计学的方法设计开发了Siri最早的原型。  
从将统计学引入AI研究后，直至近期大家所熟知的阿尔法go，AI的侧重之一就是机器学习。  
基于由人类产生的大量数据，使用人类思维去分析标记，然后引入机器进行学习，最终让机器掌握规则和规律进行工作。  

不难发现：统计学和AI有了一个共同的研究对象——数据。  

![](_pic/Stat-AI.jpeg)  

* 统计学概念在AI中的应用  

统计学作为交叉学科之一推动着人工智能的发展，在发展中逐渐被应用于各行各业。  

1. 应用于调查数据  
2. 应用于建造模型  

